/****************************************************************************
** Meta object code from reading C++ file 'KReportScriptField.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/items/field/KReportScriptField.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportScriptField.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Scripting__Field_t {
    QByteArrayData data[24];
    char stringdata0[330];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Scripting__Field_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Scripting__Field_t qt_meta_stringdata_Scripting__Field = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Scripting::Field"
QT_MOC_LITERAL(1, 17, 6), // "source"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 9), // "setSource"
QT_MOC_LITERAL(4, 35, 19), // "horizontalAlignment"
QT_MOC_LITERAL(5, 55, 21), // "setHorizonalAlignment"
QT_MOC_LITERAL(6, 77, 17), // "verticalAlignment"
QT_MOC_LITERAL(7, 95, 20), // "setVerticalAlignment"
QT_MOC_LITERAL(8, 116, 15), // "backgroundColor"
QT_MOC_LITERAL(9, 132, 18), // "setBackgroundColor"
QT_MOC_LITERAL(10, 151, 15), // "foregroundColor"
QT_MOC_LITERAL(11, 167, 18), // "setForegroundColor"
QT_MOC_LITERAL(12, 186, 17), // "backgroundOpacity"
QT_MOC_LITERAL(13, 204, 20), // "setBackgroundOpacity"
QT_MOC_LITERAL(14, 225, 9), // "lineColor"
QT_MOC_LITERAL(15, 235, 12), // "setLineColor"
QT_MOC_LITERAL(16, 248, 10), // "lineWeight"
QT_MOC_LITERAL(17, 259, 13), // "setLineWeight"
QT_MOC_LITERAL(18, 273, 9), // "lineStyle"
QT_MOC_LITERAL(19, 283, 12), // "setLineStyle"
QT_MOC_LITERAL(20, 296, 8), // "position"
QT_MOC_LITERAL(21, 305, 11), // "setPosition"
QT_MOC_LITERAL(22, 317, 4), // "size"
QT_MOC_LITERAL(23, 322, 7) // "setSize"

    },
    "Scripting::Field\0source\0\0setSource\0"
    "horizontalAlignment\0setHorizonalAlignment\0"
    "verticalAlignment\0setVerticalAlignment\0"
    "backgroundColor\0setBackgroundColor\0"
    "foregroundColor\0setForegroundColor\0"
    "backgroundOpacity\0setBackgroundOpacity\0"
    "lineColor\0setLineColor\0lineWeight\0"
    "setLineWeight\0lineStyle\0setLineStyle\0"
    "position\0setPosition\0size\0setSize"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Scripting__Field[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  124,    2, 0x0a /* Public */,
       3,    1,  125,    2, 0x0a /* Public */,
       4,    0,  128,    2, 0x0a /* Public */,
       5,    1,  129,    2, 0x0a /* Public */,
       6,    0,  132,    2, 0x0a /* Public */,
       7,    1,  133,    2, 0x0a /* Public */,
       8,    0,  136,    2, 0x0a /* Public */,
       9,    1,  137,    2, 0x0a /* Public */,
      10,    0,  140,    2, 0x0a /* Public */,
      11,    1,  141,    2, 0x0a /* Public */,
      12,    0,  144,    2, 0x0a /* Public */,
      13,    1,  145,    2, 0x0a /* Public */,
      14,    0,  148,    2, 0x0a /* Public */,
      15,    1,  149,    2, 0x0a /* Public */,
      16,    0,  152,    2, 0x0a /* Public */,
      17,    1,  153,    2, 0x0a /* Public */,
      18,    0,  156,    2, 0x0a /* Public */,
      19,    1,  157,    2, 0x0a /* Public */,
      20,    0,  160,    2, 0x0a /* Public */,
      21,    1,  161,    2, 0x0a /* Public */,
      22,    0,  164,    2, 0x0a /* Public */,
      23,    1,  165,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::QColor,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::QColor,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::QColor,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::QPointF,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::QSizeF,
    QMetaType::Void, QMetaType::QSizeF,    2,

       0        // eod
};

void Scripting::Field::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Field *_t = static_cast<Field *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QString _r = _t->source();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->setSource((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: { int _r = _t->horizontalAlignment();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setHorizonalAlignment((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: { int _r = _t->verticalAlignment();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setVerticalAlignment((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: { QColor _r = _t->backgroundColor();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 8: { QColor _r = _t->foregroundColor();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 10: { int _r = _t->backgroundOpacity();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setBackgroundOpacity((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: { QColor _r = _t->lineColor();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setLineColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 14: { int _r = _t->lineWeight();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setLineWeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: { int _r = _t->lineStyle();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setLineStyle((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: { QPointF _r = _t->position();
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setPosition((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 20: { QSizeF _r = _t->size();
            if (_a[0]) *reinterpret_cast< QSizeF*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->setSize((*reinterpret_cast< const QSizeF(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Scripting::Field::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Scripting__Field.data,
      qt_meta_data_Scripting__Field,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Scripting::Field::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Scripting::Field::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Scripting__Field.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Scripting::Field::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
