/****************************************************************************
** Meta object code from reading C++ file 'KReportRuler_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/wrtembed/KReportRuler_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportRuler_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReportRuler_t {
    QByteArrayData data[53];
    char stringdata0[645];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReportRuler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReportRuler_t qt_meta_stringdata_KReportRuler = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KReportRuler"
QT_MOC_LITERAL(1, 13, 14), // "indentsChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 5), // "final"
QT_MOC_LITERAL(4, 35, 10), // "tabChanged"
QT_MOC_LITERAL(5, 46, 16), // "originalTabIndex"
QT_MOC_LITERAL(6, 63, 18), // "KReportRuler::Tab*"
QT_MOC_LITERAL(7, 82, 3), // "tab"
QT_MOC_LITERAL(8, 86, 13), // "aboutToChange"
QT_MOC_LITERAL(9, 100, 14), // "hotSpotChanged"
QT_MOC_LITERAL(10, 115, 2), // "id"
QT_MOC_LITERAL(11, 118, 11), // "newPosition"
QT_MOC_LITERAL(12, 130, 16), // "guideLineCreated"
QT_MOC_LITERAL(13, 147, 15), // "Qt::Orientation"
QT_MOC_LITERAL(14, 163, 11), // "orientation"
QT_MOC_LITERAL(15, 175, 12), // "viewPosition"
QT_MOC_LITERAL(16, 188, 7), // "setUnit"
QT_MOC_LITERAL(17, 196, 11), // "KReportUnit"
QT_MOC_LITERAL(18, 208, 4), // "unit"
QT_MOC_LITERAL(19, 213, 9), // "setOffset"
QT_MOC_LITERAL(20, 223, 6), // "offset"
QT_MOC_LITERAL(21, 230, 14), // "setRulerLength"
QT_MOC_LITERAL(22, 245, 6), // "length"
QT_MOC_LITERAL(23, 252, 14), // "setActiveRange"
QT_MOC_LITERAL(24, 267, 5), // "start"
QT_MOC_LITERAL(25, 273, 3), // "end"
QT_MOC_LITERAL(26, 277, 22), // "setOverrideActiveRange"
QT_MOC_LITERAL(27, 300, 14), // "setRightToLeft"
QT_MOC_LITERAL(28, 315, 13), // "isRightToLeft"
QT_MOC_LITERAL(29, 329, 14), // "setShowIndents"
QT_MOC_LITERAL(30, 344, 4), // "show"
QT_MOC_LITERAL(31, 349, 18), // "setFirstLineIndent"
QT_MOC_LITERAL(32, 368, 6), // "indent"
QT_MOC_LITERAL(33, 375, 18), // "setParagraphIndent"
QT_MOC_LITERAL(34, 394, 12), // "setEndIndent"
QT_MOC_LITERAL(35, 407, 20), // "setShowMousePosition"
QT_MOC_LITERAL(36, 428, 21), // "updateMouseCoordinate"
QT_MOC_LITERAL(37, 450, 10), // "coordinate"
QT_MOC_LITERAL(38, 461, 23), // "setShowSelectionBorders"
QT_MOC_LITERAL(39, 485, 22), // "updateSelectionBorders"
QT_MOC_LITERAL(40, 508, 5), // "first"
QT_MOC_LITERAL(41, 514, 6), // "second"
QT_MOC_LITERAL(42, 521, 11), // "setShowTabs"
QT_MOC_LITERAL(43, 533, 15), // "setRelativeTabs"
QT_MOC_LITERAL(44, 549, 8), // "relative"
QT_MOC_LITERAL(45, 558, 10), // "updateTabs"
QT_MOC_LITERAL(46, 569, 10), // "QList<Tab>"
QT_MOC_LITERAL(47, 580, 4), // "tabs"
QT_MOC_LITERAL(48, 585, 11), // "tabDistance"
QT_MOC_LITERAL(49, 597, 13), // "clearHotSpots"
QT_MOC_LITERAL(50, 611, 10), // "setHotSpot"
QT_MOC_LITERAL(51, 622, 8), // "position"
QT_MOC_LITERAL(52, 631, 13) // "removeHotSpot"

    },
    "KReportRuler\0indentsChanged\0\0final\0"
    "tabChanged\0originalTabIndex\0"
    "KReportRuler::Tab*\0tab\0aboutToChange\0"
    "hotSpotChanged\0id\0newPosition\0"
    "guideLineCreated\0Qt::Orientation\0"
    "orientation\0viewPosition\0setUnit\0"
    "KReportUnit\0unit\0setOffset\0offset\0"
    "setRulerLength\0length\0setActiveRange\0"
    "start\0end\0setOverrideActiveRange\0"
    "setRightToLeft\0isRightToLeft\0"
    "setShowIndents\0show\0setFirstLineIndent\0"
    "indent\0setParagraphIndent\0setEndIndent\0"
    "setShowMousePosition\0updateMouseCoordinate\0"
    "coordinate\0setShowSelectionBorders\0"
    "updateSelectionBorders\0first\0second\0"
    "setShowTabs\0setRelativeTabs\0relative\0"
    "updateTabs\0QList<Tab>\0tabs\0tabDistance\0"
    "clearHotSpots\0setHotSpot\0position\0"
    "removeHotSpot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReportRuler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      27,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  149,    2, 0x06 /* Public */,
       4,    2,  152,    2, 0x06 /* Public */,
       8,    0,  157,    2, 0x06 /* Public */,
       9,    2,  158,    2, 0x06 /* Public */,
      12,    2,  163,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    1,  168,    2, 0x0a /* Public */,
      19,    1,  171,    2, 0x0a /* Public */,
      21,    1,  174,    2, 0x0a /* Public */,
      23,    2,  177,    2, 0x0a /* Public */,
      26,    2,  182,    2, 0x0a /* Public */,
      27,    1,  187,    2, 0x0a /* Public */,
      29,    1,  190,    2, 0x0a /* Public */,
      31,    1,  193,    2, 0x0a /* Public */,
      33,    1,  196,    2, 0x0a /* Public */,
      34,    1,  199,    2, 0x0a /* Public */,
      35,    1,  202,    2, 0x0a /* Public */,
      36,    1,  205,    2, 0x0a /* Public */,
      38,    1,  208,    2, 0x0a /* Public */,
      39,    2,  211,    2, 0x0a /* Public */,
      42,    1,  216,    2, 0x0a /* Public */,
      43,    1,  219,    2, 0x0a /* Public */,
      45,    2,  222,    2, 0x0a /* Public */,
      47,    0,  227,    2, 0x0a /* Public */,
      49,    0,  228,    2, 0x0a /* Public */,
      50,    2,  229,    2, 0x0a /* Public */,
      50,    1,  234,    2, 0x2a /* Public | MethodCloned */,
      52,    1,  237,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 6,    5,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal,   10,   11,
    QMetaType::Void, 0x80000000 | 13, QMetaType::QReal,   14,   15,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, QMetaType::Int,   20,
    QMetaType::Void, QMetaType::QReal,   22,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   24,   25,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   24,   25,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::QReal,   32,
    QMetaType::Void, QMetaType::QReal,   32,
    QMetaType::Void, QMetaType::QReal,   32,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Int,   37,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   40,   41,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   44,
    QMetaType::Void, 0x80000000 | 46, QMetaType::QReal,   47,   48,
    0x80000000 | 46,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal, QMetaType::Int,   51,   10,
    QMetaType::Void, QMetaType::QReal,   51,
    QMetaType::Bool, QMetaType::Int,   10,

       0        // eod
};

void KReportRuler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReportRuler *_t = static_cast<KReportRuler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->indentsChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->tabChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< KReportRuler::Tab*(*)>(_a[2]))); break;
        case 2: _t->aboutToChange(); break;
        case 3: _t->hotSpotChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 4: _t->guideLineCreated((*reinterpret_cast< Qt::Orientation(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 5: _t->setUnit((*reinterpret_cast< const KReportUnit(*)>(_a[1]))); break;
        case 6: _t->setOffset((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->setRulerLength((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 8: _t->setActiveRange((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 9: _t->setOverrideActiveRange((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 10: _t->setRightToLeft((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setShowIndents((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->setFirstLineIndent((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 13: _t->setParagraphIndent((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 14: _t->setEndIndent((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 15: _t->setShowMousePosition((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->updateMouseCoordinate((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->setShowSelectionBorders((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->updateSelectionBorders((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 19: _t->setShowTabs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->setRelativeTabs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->updateTabs((*reinterpret_cast< const QList<Tab>(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 22: { QList<Tab> _r = _t->tabs();
            if (_a[0]) *reinterpret_cast< QList<Tab>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->clearHotSpots(); break;
        case 24: _t->setHotSpot((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 25: _t->setHotSpot((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 26: { bool _r = _t->removeHotSpot((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KReportUnit >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KReportRuler::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportRuler::indentsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KReportRuler::*_t)(int , KReportRuler::Tab * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportRuler::tabChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KReportRuler::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportRuler::aboutToChange)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KReportRuler::*_t)(int , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportRuler::hotSpotChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KReportRuler::*_t)(Qt::Orientation , qreal );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportRuler::guideLineCreated)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject KReportRuler::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KReportRuler.data,
      qt_meta_data_KReportRuler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReportRuler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReportRuler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReportRuler.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KReportRuler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void KReportRuler::indentsChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KReportRuler::tabChanged(int _t1, KReportRuler::Tab * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KReportRuler::aboutToChange()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KReportRuler::hotSpotChanged(int _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KReportRuler::guideLineCreated(Qt::Orientation _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
