/****************************************************************************
** Meta object code from reading C++ file 'KReportScriptConstants.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/renderer/scripting/KReportScriptConstants.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportScriptConstants.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReportScriptConstants_t {
    QByteArrayData data[11];
    char stringdata0[126];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReportScriptConstants_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReportScriptConstants_t qt_meta_stringdata_KReportScriptConstants = {
    {
QT_MOC_LITERAL(0, 0, 22), // "KReportScriptConstants"
QT_MOC_LITERAL(1, 23, 10), // "PageNumber"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 9), // "PageTotal"
QT_MOC_LITERAL(4, 45, 8), // "PenStyle"
QT_MOC_LITERAL(5, 54, 7), // "QtNoPen"
QT_MOC_LITERAL(6, 62, 11), // "QtSolidLine"
QT_MOC_LITERAL(7, 74, 10), // "QtDashLine"
QT_MOC_LITERAL(8, 85, 9), // "QtDotLine"
QT_MOC_LITERAL(9, 95, 13), // "QtDashDotLine"
QT_MOC_LITERAL(10, 109, 16) // "QtDashDotDotLine"

    },
    "KReportScriptConstants\0PageNumber\0\0"
    "PageTotal\0PenStyle\0QtNoPen\0QtSolidLine\0"
    "QtDashLine\0QtDotLine\0QtDashDotLine\0"
    "QtDashDotDotLine"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReportScriptConstants[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       1,   26, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x0a /* Public */,
       3,    0,   25,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Int,
    QMetaType::Int,

 // enums: name, flags, count, data
       4, 0x0,    6,   30,

 // enum data: key, value
       5, uint(KReportScriptConstants::QtNoPen),
       6, uint(KReportScriptConstants::QtSolidLine),
       7, uint(KReportScriptConstants::QtDashLine),
       8, uint(KReportScriptConstants::QtDotLine),
       9, uint(KReportScriptConstants::QtDashDotLine),
      10, uint(KReportScriptConstants::QtDashDotDotLine),

       0        // eod
};

void KReportScriptConstants::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReportScriptConstants *_t = static_cast<KReportScriptConstants *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { int _r = _t->PageNumber();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 1: { int _r = _t->PageTotal();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject KReportScriptConstants::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KReportScriptConstants.data,
      qt_meta_data_KReportScriptConstants,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReportScriptConstants::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReportScriptConstants::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReportScriptConstants.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KReportScriptConstants::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
