/*
 * This file is part of the KDE project
 * Copyright (C) 2001-2007 by OpenMFG, LLC (info@openmfg.com)
 * Copyright (C) 2007-2008 by Adam Pigg (adam@piggz.co.uk)
 * Copyright (C) 2012 by Friedrich W. H. Kossebau (kossebau@kde.org)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see http://www.gnu.org/licenses/.
*/

/********************************************************************************
** Form generated from reading UI file 'KReportSectionEditor.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KREPORTSECTIONEDITOR_H
#define UI_KREPORTSECTIONEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SectionEditor
{
public:
    QGridLayout *gridLayout;
    QCheckBox *cbReportHeader;
    QCheckBox *cbReportFooter;
    QGroupBox *gbPageHeader;
    QHBoxLayout *horizontalLayout_3;
    QFormLayout *formLayout;
    QLabel *label_3;
    QCheckBox *cbHeadFirst;
    QLabel *label_4;
    QCheckBox *cbHeadEven;
    QLabel *label_5;
    QCheckBox *cbHeadAny;
    QFormLayout *formLayout_2;
    QLabel *label_6;
    QCheckBox *cbHeadLast;
    QLabel *label_7;
    QCheckBox *cbHeadOdd;
    QGroupBox *gbPageHeader_2;
    QHBoxLayout *horizontalLayout_4;
    QFormLayout *formLayout_3;
    QLabel *label_8;
    QCheckBox *cbFootFirst;
    QLabel *label_9;
    QCheckBox *cbFootEven;
    QLabel *label_10;
    QCheckBox *cbFootAny;
    QFormLayout *formLayout_4;
    QLabel *label_11;
    QCheckBox *cbFootLast;
    QLabel *label_12;
    QCheckBox *cbFootOdd;
    QGroupBox *GroupBox1;
    QHBoxLayout *hboxLayout;
    QListWidget *lbGroups;
    QVBoxLayout *lGroupSectionsButtons;

    void setupUi(QWidget *SectionEditor)
    {
        if (SectionEditor->objectName().isEmpty())
            SectionEditor->setObjectName(QStringLiteral("SectionEditor"));
        gridLayout = new QGridLayout(SectionEditor);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        cbReportHeader = new QCheckBox(SectionEditor);
        cbReportHeader->setObjectName(QStringLiteral("cbReportHeader"));

        gridLayout->addWidget(cbReportHeader, 0, 0, 1, 1);

        cbReportFooter = new QCheckBox(SectionEditor);
        cbReportFooter->setObjectName(QStringLiteral("cbReportFooter"));

        gridLayout->addWidget(cbReportFooter, 0, 1, 1, 1);

        gbPageHeader = new QGroupBox(SectionEditor);
        gbPageHeader->setObjectName(QStringLiteral("gbPageHeader"));
        horizontalLayout_3 = new QHBoxLayout(gbPageHeader);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        formLayout = new QFormLayout();
        formLayout->setObjectName(QStringLiteral("formLayout"));
        label_3 = new QLabel(gbPageHeader);
        label_3->setObjectName(QStringLiteral("label_3"));

        formLayout->setWidget(0, QFormLayout::LabelRole, label_3);

        cbHeadFirst = new QCheckBox(gbPageHeader);
        cbHeadFirst->setObjectName(QStringLiteral("cbHeadFirst"));

        formLayout->setWidget(0, QFormLayout::FieldRole, cbHeadFirst);

        label_4 = new QLabel(gbPageHeader);
        label_4->setObjectName(QStringLiteral("label_4"));

        formLayout->setWidget(1, QFormLayout::LabelRole, label_4);

        cbHeadEven = new QCheckBox(gbPageHeader);
        cbHeadEven->setObjectName(QStringLiteral("cbHeadEven"));

        formLayout->setWidget(1, QFormLayout::FieldRole, cbHeadEven);

        label_5 = new QLabel(gbPageHeader);
        label_5->setObjectName(QStringLiteral("label_5"));

        formLayout->setWidget(2, QFormLayout::LabelRole, label_5);

        cbHeadAny = new QCheckBox(gbPageHeader);
        cbHeadAny->setObjectName(QStringLiteral("cbHeadAny"));

        formLayout->setWidget(2, QFormLayout::FieldRole, cbHeadAny);


        horizontalLayout_3->addLayout(formLayout);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        label_6 = new QLabel(gbPageHeader);
        label_6->setObjectName(QStringLiteral("label_6"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, label_6);

        cbHeadLast = new QCheckBox(gbPageHeader);
        cbHeadLast->setObjectName(QStringLiteral("cbHeadLast"));

        formLayout_2->setWidget(0, QFormLayout::FieldRole, cbHeadLast);

        label_7 = new QLabel(gbPageHeader);
        label_7->setObjectName(QStringLiteral("label_7"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, label_7);

        cbHeadOdd = new QCheckBox(gbPageHeader);
        cbHeadOdd->setObjectName(QStringLiteral("cbHeadOdd"));

        formLayout_2->setWidget(1, QFormLayout::FieldRole, cbHeadOdd);


        horizontalLayout_3->addLayout(formLayout_2);


        gridLayout->addWidget(gbPageHeader, 1, 0, 1, 1);

        gbPageHeader_2 = new QGroupBox(SectionEditor);
        gbPageHeader_2->setObjectName(QStringLiteral("gbPageHeader_2"));
        horizontalLayout_4 = new QHBoxLayout(gbPageHeader_2);
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        label_8 = new QLabel(gbPageHeader_2);
        label_8->setObjectName(QStringLiteral("label_8"));

        formLayout_3->setWidget(0, QFormLayout::LabelRole, label_8);

        cbFootFirst = new QCheckBox(gbPageHeader_2);
        cbFootFirst->setObjectName(QStringLiteral("cbFootFirst"));

        formLayout_3->setWidget(0, QFormLayout::FieldRole, cbFootFirst);

        label_9 = new QLabel(gbPageHeader_2);
        label_9->setObjectName(QStringLiteral("label_9"));

        formLayout_3->setWidget(1, QFormLayout::LabelRole, label_9);

        cbFootEven = new QCheckBox(gbPageHeader_2);
        cbFootEven->setObjectName(QStringLiteral("cbFootEven"));

        formLayout_3->setWidget(1, QFormLayout::FieldRole, cbFootEven);

        label_10 = new QLabel(gbPageHeader_2);
        label_10->setObjectName(QStringLiteral("label_10"));

        formLayout_3->setWidget(2, QFormLayout::LabelRole, label_10);

        cbFootAny = new QCheckBox(gbPageHeader_2);
        cbFootAny->setObjectName(QStringLiteral("cbFootAny"));

        formLayout_3->setWidget(2, QFormLayout::FieldRole, cbFootAny);


        horizontalLayout_4->addLayout(formLayout_3);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName(QStringLiteral("formLayout_4"));
        label_11 = new QLabel(gbPageHeader_2);
        label_11->setObjectName(QStringLiteral("label_11"));

        formLayout_4->setWidget(0, QFormLayout::LabelRole, label_11);

        cbFootLast = new QCheckBox(gbPageHeader_2);
        cbFootLast->setObjectName(QStringLiteral("cbFootLast"));

        formLayout_4->setWidget(0, QFormLayout::FieldRole, cbFootLast);

        label_12 = new QLabel(gbPageHeader_2);
        label_12->setObjectName(QStringLiteral("label_12"));

        formLayout_4->setWidget(1, QFormLayout::LabelRole, label_12);

        cbFootOdd = new QCheckBox(gbPageHeader_2);
        cbFootOdd->setObjectName(QStringLiteral("cbFootOdd"));

        formLayout_4->setWidget(1, QFormLayout::FieldRole, cbFootOdd);


        horizontalLayout_4->addLayout(formLayout_4);


        gridLayout->addWidget(gbPageHeader_2, 1, 1, 1, 1);

        GroupBox1 = new QGroupBox(SectionEditor);
        GroupBox1->setObjectName(QStringLiteral("GroupBox1"));
        hboxLayout = new QHBoxLayout(GroupBox1);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        lbGroups = new QListWidget(GroupBox1);
        lbGroups->setObjectName(QStringLiteral("lbGroups"));

        hboxLayout->addWidget(lbGroups);

        lGroupSectionsButtons = new QVBoxLayout();
        lGroupSectionsButtons->setContentsMargins(0, 0, 0, 0);
        lGroupSectionsButtons->setObjectName(QStringLiteral("lGroupSectionsButtons"));

        hboxLayout->addLayout(lGroupSectionsButtons);


        gridLayout->addWidget(GroupBox1, 2, 0, 1, 2);

        QWidget::setTabOrder(cbReportHeader, cbReportFooter);
        QWidget::setTabOrder(cbReportFooter, cbHeadFirst);
        QWidget::setTabOrder(cbHeadFirst, cbHeadLast);
        QWidget::setTabOrder(cbHeadLast, cbHeadEven);
        QWidget::setTabOrder(cbHeadEven, cbHeadOdd);
        QWidget::setTabOrder(cbHeadOdd, cbHeadAny);
        QWidget::setTabOrder(cbHeadAny, cbFootFirst);
        QWidget::setTabOrder(cbFootFirst, cbFootLast);
        QWidget::setTabOrder(cbFootLast, cbFootEven);
        QWidget::setTabOrder(cbFootEven, cbFootOdd);
        QWidget::setTabOrder(cbFootOdd, cbFootAny);

        retranslateUi(SectionEditor);

        QMetaObject::connectSlotsByName(SectionEditor);
    } // setupUi

    void retranslateUi(QWidget *SectionEditor)
    {
        cbReportHeader->setText(QApplication::translate("SectionEditor", "Show report header", Q_NULLPTR));
        cbReportFooter->setText(QApplication::translate("SectionEditor", "Show report footer", Q_NULLPTR));
        gbPageHeader->setTitle(QApplication::translate("SectionEditor", "Page Header", Q_NULLPTR));
        label_3->setText(QApplication::translate("SectionEditor", "First page:", Q_NULLPTR));
        cbHeadFirst->setText(QString());
        label_4->setText(QApplication::translate("SectionEditor", "Even pages:", Q_NULLPTR));
        cbHeadEven->setText(QString());
        label_5->setText(QApplication::translate("SectionEditor", "Any pages:", Q_NULLPTR));
        cbHeadAny->setText(QString());
        label_6->setText(QApplication::translate("SectionEditor", "Last page:", Q_NULLPTR));
        cbHeadLast->setText(QString());
        label_7->setText(QApplication::translate("SectionEditor", "Odd pages:", Q_NULLPTR));
        cbHeadOdd->setText(QString());
        gbPageHeader_2->setTitle(QApplication::translate("SectionEditor", "Page Footer", Q_NULLPTR));
        label_8->setText(QApplication::translate("SectionEditor", "First page:", Q_NULLPTR));
        cbFootFirst->setText(QString());
        label_9->setText(QApplication::translate("SectionEditor", "Even pages:", Q_NULLPTR));
        cbFootEven->setText(QString());
        label_10->setText(QApplication::translate("SectionEditor", "Any pages:", Q_NULLPTR));
        cbFootAny->setText(QString());
        label_11->setText(QApplication::translate("SectionEditor", "Last page:", Q_NULLPTR));
        cbFootLast->setText(QString());
        label_12->setText(QApplication::translate("SectionEditor", "Odd pages:", Q_NULLPTR));
        cbFootOdd->setText(QString());
        GroupBox1->setTitle(QApplication::translate("SectionEditor", "Group Sections", Q_NULLPTR));
        Q_UNUSED(SectionEditor);
    } // retranslateUi

};

namespace Ui {
    class SectionEditor: public Ui_SectionEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KREPORTSECTIONEDITOR_H
