/****************************************************************************
** Meta object code from reading C++ file 'KReportScriptCheck.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/items/check/KReportScriptCheck.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportScriptCheck.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Scripting__CheckBox_t {
    QByteArrayData data[19];
    char stringdata0[205];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Scripting__CheckBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Scripting__CheckBox_t qt_meta_stringdata_Scripting__CheckBox = {
    {
QT_MOC_LITERAL(0, 0, 19), // "Scripting::CheckBox"
QT_MOC_LITERAL(1, 20, 5), // "value"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 8), // "setValue"
QT_MOC_LITERAL(4, 36, 3), // "val"
QT_MOC_LITERAL(5, 40, 10), // "checkStyle"
QT_MOC_LITERAL(6, 51, 13), // "setCheckStyle"
QT_MOC_LITERAL(7, 65, 15), // "foregroundColor"
QT_MOC_LITERAL(8, 81, 18), // "setForegroundColor"
QT_MOC_LITERAL(9, 100, 9), // "lineColor"
QT_MOC_LITERAL(10, 110, 12), // "setLineColor"
QT_MOC_LITERAL(11, 123, 10), // "lineWeight"
QT_MOC_LITERAL(12, 134, 13), // "setLineWeight"
QT_MOC_LITERAL(13, 148, 9), // "lineStyle"
QT_MOC_LITERAL(14, 158, 12), // "setLineStyle"
QT_MOC_LITERAL(15, 171, 8), // "position"
QT_MOC_LITERAL(16, 180, 11), // "setPosition"
QT_MOC_LITERAL(17, 192, 4), // "size"
QT_MOC_LITERAL(18, 197, 7) // "setSize"

    },
    "Scripting::CheckBox\0value\0\0setValue\0"
    "val\0checkStyle\0setCheckStyle\0"
    "foregroundColor\0setForegroundColor\0"
    "lineColor\0setLineColor\0lineWeight\0"
    "setLineWeight\0lineStyle\0setLineStyle\0"
    "position\0setPosition\0size\0setSize"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Scripting__CheckBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x0a /* Public */,
       3,    1,  100,    2, 0x0a /* Public */,
       3,    0,  103,    2, 0x2a /* Public | MethodCloned */,
       5,    0,  104,    2, 0x0a /* Public */,
       6,    1,  105,    2, 0x0a /* Public */,
       7,    0,  108,    2, 0x0a /* Public */,
       8,    1,  109,    2, 0x0a /* Public */,
       9,    0,  112,    2, 0x0a /* Public */,
      10,    1,  113,    2, 0x0a /* Public */,
      11,    0,  116,    2, 0x0a /* Public */,
      12,    1,  117,    2, 0x0a /* Public */,
      13,    0,  120,    2, 0x0a /* Public */,
      14,    1,  121,    2, 0x0a /* Public */,
      15,    0,  124,    2, 0x0a /* Public */,
      16,    1,  125,    2, 0x0a /* Public */,
      17,    0,  128,    2, 0x0a /* Public */,
      18,    1,  129,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::QColor,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::QColor,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::QPointF,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::QSizeF,
    QMetaType::Void, QMetaType::QSizeF,    2,

       0        // eod
};

void Scripting::CheckBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CheckBox *_t = static_cast<CheckBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->value();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->setValue((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setValue(); break;
        case 3: { QString _r = _t->checkStyle();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setCheckStyle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: { QColor _r = _t->foregroundColor();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 7: { QColor _r = _t->lineColor();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setLineColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 9: { int _r = _t->lineWeight();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setLineWeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: { int _r = _t->lineStyle();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setLineStyle((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: { QPointF _r = _t->position();
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setPosition((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 15: { QSizeF _r = _t->size();
            if (_a[0]) *reinterpret_cast< QSizeF*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setSize((*reinterpret_cast< const QSizeF(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Scripting::CheckBox::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Scripting__CheckBox.data,
      qt_meta_data_Scripting__CheckBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Scripting::CheckBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Scripting::CheckBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Scripting__CheckBox.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Scripting::CheckBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
