/****************************************************************************
** Meta object code from reading C++ file 'KReportScriptHandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/renderer/scripting/KReportScriptHandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportScriptHandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReportScriptHandler_t {
    QByteArrayData data[14];
    char stringdata0[165];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReportScriptHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReportScriptHandler_t qt_meta_stringdata_KReportScriptHandler = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KReportScriptHandler"
QT_MOC_LITERAL(1, 21, 12), // "groupChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 9), // "groupData"
QT_MOC_LITERAL(4, 45, 18), // "slotEnteredSection"
QT_MOC_LITERAL(5, 64, 19), // "KReportSectionData*"
QT_MOC_LITERAL(6, 84, 8), // "OROPage*"
QT_MOC_LITERAL(7, 93, 16), // "slotEnteredGroup"
QT_MOC_LITERAL(8, 110, 15), // "slotExitedGroup"
QT_MOC_LITERAL(9, 126, 13), // "setPageNumber"
QT_MOC_LITERAL(10, 140, 1), // "p"
QT_MOC_LITERAL(11, 142, 12), // "setPageTotal"
QT_MOC_LITERAL(12, 155, 1), // "t"
QT_MOC_LITERAL(13, 157, 7) // "newPage"

    },
    "KReportScriptHandler\0groupChanged\0\0"
    "groupData\0slotEnteredSection\0"
    "KReportSectionData*\0OROPage*\0"
    "slotEnteredGroup\0slotExitedGroup\0"
    "setPageNumber\0p\0setPageTotal\0t\0newPage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReportScriptHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    3,   52,    2, 0x0a /* Public */,
       7,    2,   59,    2, 0x0a /* Public */,
       8,    2,   64,    2, 0x0a /* Public */,
       9,    1,   69,    2, 0x0a /* Public */,
      11,    1,   72,    2, 0x0a /* Public */,
      13,    0,   75,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariantMap,    3,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 6, QMetaType::QPointF,    2,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    2,    2,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,

       0        // eod
};

void KReportScriptHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReportScriptHandler *_t = static_cast<KReportScriptHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->groupChanged((*reinterpret_cast< const QMap<QString,QVariant>(*)>(_a[1]))); break;
        case 1: _t->slotEnteredSection((*reinterpret_cast< KReportSectionData*(*)>(_a[1])),(*reinterpret_cast< OROPage*(*)>(_a[2])),(*reinterpret_cast< QPointF(*)>(_a[3]))); break;
        case 2: _t->slotEnteredGroup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 3: _t->slotExitedGroup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 4: _t->setPageNumber((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setPageTotal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->newPage(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KReportScriptHandler::*_t)(const QMap<QString,QVariant> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportScriptHandler::groupChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KReportScriptHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KReportScriptHandler.data,
      qt_meta_data_KReportScriptHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReportScriptHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReportScriptHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReportScriptHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KReportScriptHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KReportScriptHandler::groupChanged(const QMap<QString,QVariant> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
