/****************************************************************************
** Meta object code from reading C++ file 'KReportScriptImage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/items/image/KReportScriptImage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportScriptImage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Scripting__Image_t {
    QByteArrayData data[10];
    char stringdata0[105];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Scripting__Image_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Scripting__Image_t qt_meta_stringdata_Scripting__Image = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Scripting::Image"
QT_MOC_LITERAL(1, 17, 8), // "position"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 11), // "setPosition"
QT_MOC_LITERAL(4, 39, 4), // "size"
QT_MOC_LITERAL(5, 44, 7), // "setSize"
QT_MOC_LITERAL(6, 52, 10), // "resizeMode"
QT_MOC_LITERAL(7, 63, 13), // "setResizeMode"
QT_MOC_LITERAL(8, 77, 14), // "setInlineImage"
QT_MOC_LITERAL(9, 92, 12) // "loadFromFile"

    },
    "Scripting::Image\0position\0\0setPosition\0"
    "size\0setSize\0resizeMode\0setResizeMode\0"
    "setInlineImage\0loadFromFile"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Scripting__Image[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x0a /* Public */,
       3,    1,   55,    2, 0x0a /* Public */,
       4,    0,   58,    2, 0x0a /* Public */,
       5,    1,   59,    2, 0x0a /* Public */,
       6,    0,   62,    2, 0x0a /* Public */,
       7,    1,   63,    2, 0x0a /* Public */,
       8,    1,   66,    2, 0x0a /* Public */,
       9,    1,   69,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::QPointF,
    QMetaType::Void, QMetaType::QPointF,    2,
    QMetaType::QSizeF,
    QMetaType::Void, QMetaType::QSizeF,    2,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QByteArray,    2,
    QMetaType::Void, QMetaType::QVariant,    2,

       0        // eod
};

void Scripting::Image::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Image *_t = static_cast<Image *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QPointF _r = _t->position();
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->setPosition((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 2: { QSizeF _r = _t->size();
            if (_a[0]) *reinterpret_cast< QSizeF*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setSize((*reinterpret_cast< const QSizeF(*)>(_a[1]))); break;
        case 4: { QString _r = _t->resizeMode();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->setResizeMode((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->setInlineImage((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 7: _t->loadFromFile((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Scripting::Image::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Scripting__Image.data,
      qt_meta_data_Scripting__Image,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Scripting::Image::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Scripting::Image::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Scripting__Image.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Scripting::Image::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
