/****************************************************************************
** Shared Class code from reading file 'KReportElement.shared.h'
**
** Created
**      by: The Shared Data Compiler version 0.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "KReportElement.h"
#include <QVariant>

template<>
KREPORT_EXPORT KReportElement::Data *QSharedDataPointer<KReportElement::Data>::clone()
{
    return d->clone();
}
