/****************************************************************************
** Meta object code from reading C++ file 'KReportSectionEditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/wrtembed/KReportSectionEditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportSectionEditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReportSectionEditor_t {
    QByteArrayData data[25];
    char stringdata0[421];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReportSectionEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReportSectionEditor_t qt_meta_stringdata_KReportSectionEditor = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KReportSectionEditor"
QT_MOC_LITERAL(1, 21, 22), // "cbReportHeader_toggled"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 3), // "yes"
QT_MOC_LITERAL(4, 49, 22), // "cbReportFooter_toggled"
QT_MOC_LITERAL(5, 72, 19), // "cbHeadFirst_toggled"
QT_MOC_LITERAL(6, 92, 18), // "cbHeadLast_toggled"
QT_MOC_LITERAL(7, 111, 18), // "cbHeadEven_toggled"
QT_MOC_LITERAL(8, 130, 17), // "cbHeadOdd_toggled"
QT_MOC_LITERAL(9, 148, 19), // "cbFootFirst_toggled"
QT_MOC_LITERAL(10, 168, 18), // "cbFootLast_toggled"
QT_MOC_LITERAL(11, 187, 18), // "cbFootEven_toggled"
QT_MOC_LITERAL(12, 206, 17), // "cbFootOdd_toggled"
QT_MOC_LITERAL(13, 224, 17), // "cbHeadAny_toggled"
QT_MOC_LITERAL(14, 242, 17), // "cbFootAny_toggled"
QT_MOC_LITERAL(15, 260, 14), // "btnAdd_clicked"
QT_MOC_LITERAL(16, 275, 15), // "btnEdit_clicked"
QT_MOC_LITERAL(17, 291, 17), // "btnRemove_clicked"
QT_MOC_LITERAL(18, 309, 17), // "btnMoveUp_clicked"
QT_MOC_LITERAL(19, 327, 19), // "brnMoveDown_clicked"
QT_MOC_LITERAL(20, 347, 20), // "updateButtonsForItem"
QT_MOC_LITERAL(21, 368, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(22, 385, 11), // "currentItem"
QT_MOC_LITERAL(23, 397, 19), // "updateButtonsForRow"
QT_MOC_LITERAL(24, 417, 3) // "row"

    },
    "KReportSectionEditor\0cbReportHeader_toggled\0"
    "\0yes\0cbReportFooter_toggled\0"
    "cbHeadFirst_toggled\0cbHeadLast_toggled\0"
    "cbHeadEven_toggled\0cbHeadOdd_toggled\0"
    "cbFootFirst_toggled\0cbFootLast_toggled\0"
    "cbFootEven_toggled\0cbFootOdd_toggled\0"
    "cbHeadAny_toggled\0cbFootAny_toggled\0"
    "btnAdd_clicked\0btnEdit_clicked\0"
    "btnRemove_clicked\0btnMoveUp_clicked\0"
    "brnMoveDown_clicked\0updateButtonsForItem\0"
    "QListWidgetItem*\0currentItem\0"
    "updateButtonsForRow\0row"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReportSectionEditor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  109,    2, 0x08 /* Private */,
       4,    1,  112,    2, 0x08 /* Private */,
       5,    1,  115,    2, 0x08 /* Private */,
       6,    1,  118,    2, 0x08 /* Private */,
       7,    1,  121,    2, 0x08 /* Private */,
       8,    1,  124,    2, 0x08 /* Private */,
       9,    1,  127,    2, 0x08 /* Private */,
      10,    1,  130,    2, 0x08 /* Private */,
      11,    1,  133,    2, 0x08 /* Private */,
      12,    1,  136,    2, 0x08 /* Private */,
      13,    1,  139,    2, 0x08 /* Private */,
      14,    1,  142,    2, 0x08 /* Private */,
      15,    0,  145,    2, 0x08 /* Private */,
      16,    0,  146,    2, 0x08 /* Private */,
      17,    0,  147,    2, 0x08 /* Private */,
      18,    0,  148,    2, 0x08 /* Private */,
      19,    0,  149,    2, 0x08 /* Private */,
      20,    1,  150,    2, 0x08 /* Private */,
      23,    1,  153,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::Int,   24,

       0        // eod
};

void KReportSectionEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReportSectionEditor *_t = static_cast<KReportSectionEditor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->cbReportHeader_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->cbReportFooter_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->cbHeadFirst_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->cbHeadLast_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->cbHeadEven_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->cbHeadOdd_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->cbFootFirst_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->cbFootLast_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->cbFootEven_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->cbFootOdd_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->cbHeadAny_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->cbFootAny_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->btnAdd_clicked(); break;
        case 13: _t->btnEdit_clicked(); break;
        case 14: _t->btnRemove_clicked(); break;
        case 15: _t->btnMoveUp_clicked(); break;
        case 16: _t->brnMoveDown_clicked(); break;
        case 17: _t->updateButtonsForItem((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 18: _t->updateButtonsForRow((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KReportSectionEditor::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_KReportSectionEditor.data,
      qt_meta_data_KReportSectionEditor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReportSectionEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReportSectionEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReportSectionEditor.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KReportSectionEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
