/****************************************************************************
** Meta object code from reading C++ file 'KReportScriptSection.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/renderer/scripting/KReportScriptSection.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportScriptSection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Scripting__Section_t {
    QByteArrayData data[13];
    char stringdata0[141];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Scripting__Section_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Scripting__Section_t qt_meta_stringdata_Scripting__Section = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Scripting::Section"
QT_MOC_LITERAL(1, 19, 15), // "backgroundColor"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 18), // "setBackgroundColor"
QT_MOC_LITERAL(4, 55, 6), // "height"
QT_MOC_LITERAL(5, 62, 9), // "setHeight"
QT_MOC_LITERAL(6, 72, 4), // "name"
QT_MOC_LITERAL(7, 77, 14), // "objectByNumber"
QT_MOC_LITERAL(8, 92, 12), // "objectByName"
QT_MOC_LITERAL(9, 105, 10), // "initialize"
QT_MOC_LITERAL(10, 116, 8), // "QJSValue"
QT_MOC_LITERAL(11, 125, 1), // "s"
QT_MOC_LITERAL(12, 127, 13) // "eventOnRender"

    },
    "Scripting::Section\0backgroundColor\0\0"
    "setBackgroundColor\0height\0setHeight\0"
    "name\0objectByNumber\0objectByName\0"
    "initialize\0QJSValue\0s\0eventOnRender"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Scripting__Section[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x0a /* Public */,
       3,    1,   60,    2, 0x0a /* Public */,
       4,    0,   63,    2, 0x0a /* Public */,
       5,    1,   64,    2, 0x0a /* Public */,
       6,    0,   67,    2, 0x0a /* Public */,
       7,    1,   68,    2, 0x0a /* Public */,
       8,    1,   71,    2, 0x0a /* Public */,
       9,    1,   74,    2, 0x0a /* Public */,
      12,    0,   77,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::QColor,
    QMetaType::Void, QMetaType::QColor,    2,
    QMetaType::QReal,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::QString,
    QMetaType::QObjectStar, QMetaType::Int,    2,
    QMetaType::QObjectStar, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,

       0        // eod
};

void Scripting::Section::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Section *_t = static_cast<Section *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { QColor _r = _t->backgroundColor();
            if (_a[0]) *reinterpret_cast< QColor*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->setBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 2: { qreal _r = _t->height();
            if (_a[0]) *reinterpret_cast< qreal*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setHeight((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 4: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QObject* _r = _t->objectByNumber((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 6: { QObject* _r = _t->objectByName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QObject**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->initialize((*reinterpret_cast< const QJSValue(*)>(_a[1]))); break;
        case 8: _t->eventOnRender(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject Scripting::Section::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Scripting__Section.data,
      qt_meta_data_Scripting__Section,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Scripting::Section::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Scripting::Section::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Scripting__Section.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Scripting::Section::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
