/****************************************************************************
** Meta object code from reading C++ file 'KReportPreRenderer_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kreport-3.0.2/src/renderer/KReportPreRenderer_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'KReportPreRenderer_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KReportPreRendererPrivate_t {
    QByteArrayData data[9];
    char stringdata0[139];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KReportPreRendererPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KReportPreRendererPrivate_t qt_meta_stringdata_KReportPreRendererPrivate = {
    {
QT_MOC_LITERAL(0, 0, 25), // "KReportPreRendererPrivate"
QT_MOC_LITERAL(1, 26, 12), // "enteredGroup"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 11), // "exitedGroup"
QT_MOC_LITERAL(4, 52, 16), // "renderingSection"
QT_MOC_LITERAL(5, 69, 19), // "KReportSectionData*"
QT_MOC_LITERAL(6, 89, 8), // "OROPage*"
QT_MOC_LITERAL(7, 98, 21), // "finishedAllASyncItems"
QT_MOC_LITERAL(8, 120, 18) // "asyncItemsFinished"

    },
    "KReportPreRendererPrivate\0enteredGroup\0"
    "\0exitedGroup\0renderingSection\0"
    "KReportSectionData*\0OROPage*\0"
    "finishedAllASyncItems\0asyncItemsFinished"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KReportPreRendererPrivate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,
       3,    2,   44,    2, 0x06 /* Public */,
       4,    3,   49,    2, 0x06 /* Public */,
       7,    0,   56,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   57,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    2,    2,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 6, QMetaType::QPointF,    2,    2,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void KReportPreRendererPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KReportPreRendererPrivate *_t = static_cast<KReportPreRendererPrivate *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->enteredGroup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 1: _t->exitedGroup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 2: _t->renderingSection((*reinterpret_cast< KReportSectionData*(*)>(_a[1])),(*reinterpret_cast< OROPage*(*)>(_a[2])),(*reinterpret_cast< QPointF(*)>(_a[3]))); break;
        case 3: _t->finishedAllASyncItems(); break;
        case 4: _t->asyncItemsFinished(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KReportSectionData* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KReportPreRendererPrivate::*_t)(const QString & , const QVariant & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportPreRendererPrivate::enteredGroup)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KReportPreRendererPrivate::*_t)(const QString & , const QVariant & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportPreRendererPrivate::exitedGroup)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KReportPreRendererPrivate::*_t)(KReportSectionData * , OROPage * , QPointF );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportPreRendererPrivate::renderingSection)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KReportPreRendererPrivate::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KReportPreRendererPrivate::finishedAllASyncItems)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject KReportPreRendererPrivate::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KReportPreRendererPrivate.data,
      qt_meta_data_KReportPreRendererPrivate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KReportPreRendererPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KReportPreRendererPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KReportPreRendererPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KReportPreRendererPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KReportPreRendererPrivate::enteredGroup(const QString & _t1, const QVariant & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KReportPreRendererPrivate::exitedGroup(const QString & _t1, const QVariant & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KReportPreRendererPrivate::renderingSection(KReportSectionData * _t1, OROPage * _t2, QPointF _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KReportPreRendererPrivate::finishedAllASyncItems()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
